@@ -123,12 +123,3 @@ class TestJobs(unittest.TestCase):
         actual_job_id = jobs.post_job_existing_cluster(self.api_mock, self.project_name, self.script_name, cluster_id,
             job_type=jobs.JOB_TYPE_SPARK_ON_JOBSERVER)
         self.assertEquals(expected_job_id, actual_job_id)
-
-    def test_post_job_existing_cluster_with_use_vpc_for_emr(self):
-        cluster_id = 'xyz123fdsa'
-        expected_job_id = 'abcdefghijklmnop'
-        emr_release_label = 'some.version'
-        self.api_mock.post.return_value = {'job_id': expected_job_id}
-        actual_job_id = jobs.post_job_new_cluster(self.api_mock, self.project_name, self.script_name, cluster_id,
-                                                  use_vpc_for_emr=True)
-        self.assertEquals(expected_job_id, actual_job_id)
\ No newline at end of file
